@@ -41,29 +41,27 @@ logging.config.dictConfig({
 })
 LOGGER = logging.getLogger('aws-ec2-assign-eip')
 
+REGION = args.region
+
 # Fetch instance metadata
 METADATA = get_instance_metadata(timeout=1, num_retries=1)
 if METADATA:
     try:
-        PROFILE_NAME = METADATA['iam']['info'][u'InstanceProfileArn']
         REGION = METADATA['placement']['availability-zone'][:-1]
     except KeyError:
-        PROFILE_NAME = None
+        pass
 
 # Connect to AWS EC2
 if args.access_key or args.secret_key:
     # Use command line credentials
     CONNECTION = connect_to_region(
-        args.region,
+        REGION,
         aws_access_key_id=args.access_key,
         aws_secret_access_key=args.secret_key)
-elif PROFILE_NAME:
-    # Use instance profile
-    CONNECTION = connect_to_region(REGION, profile_name=PROFILE_NAME)
 else:
-    # Use environment vars or global boto configuration
-    CONNECTION = connect_to_region(args.region)
-LOGGER.info('Connected to AWS EC2 in {}'.format(args.region))
+    # Use environment vars or global boto configuration or instance metadata
+    CONNECTION = connect_to_region(REGION)
+LOGGER.info('Connected to AWS EC2 in {}'.format(REGION))
 
 
 def main():
